@@ -34,19 +34,19 @@
 
 int main( int argc, char ** argv )
 {
-    QCoreApplication::setApplicationName("kvtml-converter");
-    QCoreApplication::setApplicationVersion("0.2");
-    QCoreApplication::setOrganizationDomain("kde.org");
+    QCoreApplication::setApplicationName(QStringLiteral("kvtml-converter"));
+    QCoreApplication::setApplicationVersion(QStringLiteral("0.2"));
+    QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
     QCoreApplication app( argc, argv );
 
     QCommandLineParser parser;
     parser.addHelpOption();
     parser.addVersionOption();
-    QCommandLineOption formatOption(QStringList() << "f" << "format",
+    QCommandLineOption formatOption(QStringList() << QStringLiteral("f") << QStringLiteral("format"),
             i18nc("main", "file format to write out (kvtml1, kvtml2, or csv)."));
     parser.addOption(formatOption);
-    parser.addPositionalArgument("infile", i18nc("main", "File to read in."));
-    parser.addPositionalArgument("outfile", i18nc("main", "File to write to."));
+    parser.addPositionalArgument(QStringLiteral("infile"), i18nc("main", "File to read in."));
+    parser.addPositionalArgument(QStringLiteral("outfile"), i18nc("main", "File to write to."));
 
     parser.process(app);
 
@@ -61,11 +61,11 @@ int main( int argc, char ** argv )
             qDebug() << "Reading " << infile;
             document.open( infile );
             qDebug() << "Writing to " << outfile;
-            if (parser.value("f") == "kvtml1")
+            if (parser.value(QStringLiteral("f")) == QLatin1String("kvtml1"))
             {
                 document.saveAs( outfile, KEduVocDocument::Kvtml1 );
             }
-            else if (parser.value("f") == "csv")
+            else if (parser.value(QStringLiteral("f")) == QLatin1String("csv"))
             {
                 document.saveAs( outfile, KEduVocDocument::Csv );
             }
